const mongoose = require('mongoose')
const applyTokenModel = require('../model/token')

// token repository
// using to query token in database
// params
//  - db <connection>: instance of mongoose connection
// return instance of token repository
function TokenRepository (db) {
  const self = this

  self.db = db
  applyTokenModel(mongoose, db)
  self.model = db.models.token
}

// shortcut to repository prototype
// using to access to repositoy prototype more quickly
var prototype = TokenRepository.prototype

// create new token record and remove old record match with access_token
// params
//  - item <object>: token record object
//  - callback <function>: function will call
//    params
//     - error <object>: error during process
prototype.create = function (oldAccessToken, item, callback) {
  const self = this

  self.model.remove({access_token: oldAccessToken}, function (errRemove) {
    if (errRemove) {
      callback(errRemove)
      return
    }

    self.model.create(item, function (errCreate) {
      callback(errCreate)
    })
  })
}

// find token record by access_token
// params
//  - access_token: to find
//  - callback: function will be call after done
//    params
//     - item: token record has found
//     - error <object>: error during process
prototype.findAccessToken = function (accessToken, callback) {
  this.model.findOne({access_token: accessToken}, function (err, item) {
    callback(err, item)
  })
}

// export module
module.exports = TokenRepository
