const jsonfile = require('jsonfile')
const fs = require('fs')
const async = require('async')

const SchedulerRepo = require('../repository/scheduler')
const randstr = require('./randstr')

// import from file to database
// file in json format
// params
//  - opts: object contains options
//    - dir <string>: path to data directory. each file in  directory is one
//      scheduler
//    - db <mongo>: instance of mongodb
//  - callback <function>: function will call
//    params
//     - error <object>: error during process
module.exports = function (opts, callback) {
  const numItemGen = 512
  const schedulerRepo = new SchedulerRepo(opts.db)
  var calls = []
  var items = []

  schedulerRepo.drop(function (errDrop) {
    if (errDrop) {
      callback(errDrop)
      return
    }

    // import meaning scheduler
    fs.readdirSync(opts.dir).forEach(function (file) {
      calls.push(function (asyncCallback) {
        jsonfile.readFile(opts.dir + '/' + file, function (errFile, items) {
          if (errFile) {
            asyncCallback(errFile)
            return
          }
          // push to database
          schedulerRepo.create(items, function (errCreate) {
            asyncCallback(errCreate)
          })
        })
      })
    })

    // generate scheduler, it not mean and use to fill database
    for (var i = 0; i < numItemGen; i++) {
      items.push({
        name: randstr(16),
        notes: randstr(1024),
        tags: ['home', 'relax', 'holiday'],
        tasks: [
          {start: '00:00', action: randstr(16)},
          {start: '03:00', action: randstr(16)},
          {start: '06:00', action: randstr(16)},
          {start: '09:00', action: randstr(16)},
          {start: '12:00', action: randstr(16)},
          {start: '15:00', action: randstr(16)},
          {start: '18:00', action: randstr(16)},
          {start: '21:00', action: randstr(16)}
        ]
      })
    }

    calls.push(function (asyncCallback) {
      schedulerRepo.create(items, function (errCreate) {
        asyncCallback(errCreate)
      })
    })

    // execute
    async.series(calls, function (seriesErr) {
      callback(seriesErr)
    })
  })
}
